# HerdingCATs 🐈‍⬛

[![codecov](https://codecov.io/gh/CHRISCARLON/Herding-CATs/graph/badge.svg?token=Y9Z0QA39S3)](https://codecov.io/gh/CHRISCARLON/Herding-CATs)

[Documentation](https://herdingcats.dev)📚

> [!NOTE]  
> Version 0.1.2 PyPi is now available .
>
> HerdingCATs is currently under active development.
>
> Features may change as the project evolves.

---

**The aim of this project is simple...**

Speed up how data analysts explore and interact with open data sources.

- Navigate the open data ecosystem
- Find the data that you need
- Get that data into a format and/or location for further analysis

**Install Commands:**

```bash
pip install HerdCats
```

or

```bash
poetry add HerdCats
```

or

```bash
uv add HerdCats
```

---

## Contributing

Contributions are welcome! Please feel free to submit a PR.

For major changes, please open an issue first to discuss what you would like to change.
